Class: Decidim::Demographics::Admin::PublishResponsesController

Inherits:
ApplicationController
  • Object
show all
Includes:
Forms::Admin::Concerns::HasQuestionnaireResponsesUrlHelper
Defined in:
app/controllers/decidim/demographics/admin/publish_responses_controller.rb

Overview

Mind that even though the name of the controller, currently we do not allow the publication. This is only for showing to the admin the visualization of the responses

Instance Method Summary collapse

Instance Method Details

#indexObject



14
15
16
# File 'app/controllers/decidim/demographics/admin/publish_responses_controller.rb', line 14

def index
  enforce_permission_to(:index, :demographics)
end

#questionnaire_urlObject



18
19
20
# File 'app/controllers/decidim/demographics/admin/publish_responses_controller.rb', line 18

def questionnaire_url
  responses_path
end