Class: Decidim::Demographics::Admin::ApplicationController

Inherits:
Admin::ApplicationController
  • Object
show all
Defined in:
app/controllers/decidim/demographics/admin/application_controller.rb

Overview

This controller is the abstract class from which all other controllers of this engine inherit.

Note that it inherits from ‘Decidim::Admin::ApplicationController`, which overrides its layout and provides all kinds of useful methods.