Class: Decidim::Demographics::Engine
- Inherits:
-
Rails::Engine
- Object
- Rails::Engine
- Decidim::Demographics::Engine
- Defined in:
- lib/decidim/demographics/engine.rb
Overview
This is the engine that runs on the public interface of ‘decidim-demographics`. It handles the interaction between participant and own demographic data